@@ -19,7 +19,19 @@ fn download_filename() -> String {
 }
 
 fn get_expected_sha256(filename: &str) -> Result<sha256::Hash, ()> {
-    let sha256sums_filename = format!("sha256/bitcoin-core-{}-SHA256SUMS.asc", &VERSION);
+    let sha256sums_filename = format!("sha256/bitcoin-core-{}-SHA256SUMS", &VERSION);
+    #[cfg(any(
+        feature = "0_21_1",
+        feature = "0_21_0",
+        feature = "0_20_1",
+        feature = "0_20_0",
+        feature = "0_19_1",
+        feature = "0_19_0_1",
+        feature = "0_18_1",
+        feature = "0_18_0",
+        feature = "0_17_1",
+    ))]
+    let sha256sums_filename = format!("{}.asc", sha256sums_filename);
     let file = File::open(sha256sums_filename).map_err(|_| ())?;
     for line in BufReader::new(file).lines().flatten() {
         let tokens: Vec<_> = line.split("  ").collect();
